@@ -7,7 +7,7 @@
 "XVkbd.translations: #override \
 	<Message>WM_PROTOCOLS: DeleteWindowProc()\\n\
         <Configure>: WindowResized()\\n\
-        <MappingNotify>: ReadKeymap()\\n\
+        <MappingNotify>: MappingModified()\\n\
         <Visible>: VisibilityChanged()",
 "XVkbd.Form.translations: <BtnDown>:",
 "XVkbd.Form.?.translations: <BtnDown>:",
@@ -256,7 +256,7 @@
   french,french2,german,greek,hebrew,icelandic,italian,\
   jisx6002/ja_JP.eucJP,jisx6004/ja_JP.eucJP,korean/ko_KR.eucKR,\
   norwegian,portuguese,russian/ru_RU.KOI8-R,slovene,spanish,\
-  swedish,swissgerman,turkish,uk,latin1,small,strip",
+  swedish,swissgerman,turkish,turkishF,uk,latin1,small,strip",
 "XVkbd*layout_panel*default.label: Default",
 "XVkbd*layout_panel*belgian.label: Belgian",
 "XVkbd*layout_panel*danish.label: Danish",
@@ -279,6 +279,7 @@
 "XVkbd*layout_panel*swedish.label: Swedish",
 "XVkbd*layout_panel*swissgerman.label: Swiss/German",
 "XVkbd*layout_panel*turkish.label: Turkish",
+"XVkbd*layout_panel*turkishF.label: Turkish F",
 "XVkbd*layout_panel*uk.label: United Kingdom",
 "XVkbd*layout_panel*latin1.label: Latin-1",
 "XVkbd*layout_panel*small.label: Small Keyboard",
